@@ -1,10 +1,11 @@
 use crate::logger::{command_msg, dependency_msg, error, exit, file_msg, message};
 use anyhow::Result;
 use console::style;
-use dialoguer::{theme::ColorfulTheme, Confirm};
+use dialoguer::{theme::ColorfulTheme, Confirm, Input};
 use inflector::Inflector;
 use rust_embed::RustEmbed;
 use std::path::PathBuf;
+use crate::git;
 
 #[derive(RustEmbed)]
 #[folder = "template"]
@@ -267,19 +268,6 @@ pub fn create(project_name: &str) -> Result<()> {
         std::fs::write(file_path, file_contents)?;
     }
 
-    command_msg("chmod +x ./bin/tsync.sh");
-
-    let chmod_tsync = std::process::Command::new("chmod")
-        .current_dir(&project_dir)
-        .arg("+x")
-        .arg("./bin/tsync.sh")
-        .status()
-        .expect("failed to execute process");
-
-    if !chmod_tsync.success() {
-        error("Failed to execute `chmod +x ./bin/tsync.sh`");
-    }
-
     /*
         Finalize; create the initial commit.
     */
@@ -298,6 +286,65 @@ pub fn create(project_name: &str) -> Result<()> {
         std::process::exit(1);
     }
 
+    command_msg("git config user.name");
+
+    let git_config_user_name = git::check_config(&project_dir, "user.name");
+    
+    if !git_config_user_name {
+        message("You do not have a git user name set.");
+
+        let mut valid_user_name = false;
+        let mut invalid_input = false;
+        
+        while !valid_user_name {
+            let prompt_message = if (invalid_input) {
+                "(try again) Choose a name to use when committing:"
+            } else {
+                "Choose a name to use when committing:"
+            };
+            let input : String = Input::new()
+                .with_prompt(prompt_message)
+                .interact()?;
+
+            command_msg(&format!("git config user.name {:#?}", &input));
+            
+            if input.len() > 0 && git::set_config(&project_dir, "user.name", &input) && git::check_config(&project_dir, "user.name") {
+                valid_user_name = true;
+            } else {
+                invalid_input = true;
+            }
+        }
+    }
+
+    let git_config_user_email = git::check_config(&project_dir, "user.email");
+    
+    if !git_config_user_email {
+        message("You do not have a git user email set.");
+
+        let mut valid_user_email = false;
+        let mut invalid_input = false;
+        
+        while !valid_user_email {
+            let prompt_message = if (invalid_input) {
+                "(try again) Choose an email to use when committing:"
+            } else {
+                "Choose an email to use when committing:"
+            };
+            let input : String = Input::new()
+                .with_prompt(prompt_message)
+                .interact()?;
+
+            command_msg(&format!("git config user.email {:#?}", &input));
+            
+            if input.len() > 0 && git::set_config(&project_dir, "user.email", &input) && git::check_config(&project_dir, "user.email") {
+                valid_user_email = true;
+            } else {
+                invalid_input = true;
+            }
+        }
+        
+    }
+
     command_msg("git add -A");
 
     let git_add = std::process::Command::new("git")
